package id.go.kemenag.madrasah.pmrms.notif.service

import id.go.kemenag.madrasah.pmrms.notif.helpers.responseSuccess
import id.go.kemenag.madrasah.pmrms.notif.model.request.EmailRequest
import id.go.kemenag.madrasah.pmrms.notif.model.response.ReturnData
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.beans.factory.annotation.Value
import org.springframework.http.ResponseEntity
import org.springframework.mail.SimpleMailMessage
import org.springframework.mail.javamail.JavaMailSender
import org.springframework.stereotype.Service

@Service
class EmailService {

    @Value("\${app.name}")
    private lateinit var appName: String

    @Autowired
    private lateinit var javaMailSender: JavaMailSender

    @Value("\${spring.mail.from}")
    private lateinit var emailFrom: String

    fun sendEamil(request: EmailRequest): ResponseEntity<ReturnData> {
        return try {
            Thread {
                sendEmail(request.to, request.subject, request.message)
            }.start()
            responseSuccess()
        } catch (e: Exception) {
            throw e
        }
    }

    private fun sendEmail(to: String?, subject: String?, message: String?) {
        try {
            val msg = SimpleMailMessage()
            msg.setTo(to)
            msg.setFrom(emailFrom)
            msg.setSubject("$subject $appName")
            msg.setText(message ?: "")
            javaMailSender.send(msg)
        } catch (e: Exception) {
            throw e
        }
    }
}
